@@ -19,47 +19,40 @@
 #ifndef KMPLAYERPARTBASE_H
 #define KMPLAYERPARTBASE_H
 
+#include "config-kmplayer.h"
+
 #include "kmplayer_def.h"
 
 #include <qobject.h>
-#include <qguardedptr.h>
-#include <qvaluelist.h>
-#include <qcstring.h>
+#include <QPointer>
 #include <qstringlist.h>
 #include <qmap.h>
 
-#include <dcopobject.h>
 #include <kmediaplayer/player.h>
 #include <kurl.h>
+#include <ksharedconfig.h>
+#include <kconfiggroup.h>
 
 #include "kmplayerview.h"
 #include "kmplayersource.h"
 
 
 class KAboutData;
-class KInstance;
 class KActionCollection;
 class KBookmarkMenu;
-class KConfig;
-class QIODevice;
-class QTextStream;
+class KBookmarkManager;
+class Q3ListViewItem;
+class KMenu;
 
-namespace KIO {
-    class Job;
-}
 
 namespace KMPlayer {
-    
+
 class PartBase;
 class Process;
 class MPlayer;
 class BookmarkOwner;
-class BookmarkManager;
-class MEncoder;
-class MPlayerDumpstream;
-class FFMpeg;
-class Xine;
 class Settings;
+class MediaManager;
 
 /*
  * Source from URLs
@@ -67,42 +60,23 @@ class Settings;
 class KMPLAYER_EXPORT URLSource : public Source {
     Q_OBJECT
 public:
-    URLSource (PartBase * player, const KURL & url = KURL ());
+    URLSource (PartBase * player, const KUrl & url = KUrl ());
     virtual ~URLSource ();
 
     virtual void dimensions (int & w, int & h);
     virtual bool hasLength ();
     virtual QString prettyName ();
     virtual void reset ();
+    virtual void setUrl (const QString &url);
+    virtual bool authoriseUrl (const QString &url);
 public slots:
     virtual void init ();
     virtual void activate ();
     virtual void deactivate ();
-    virtual void playCurrent ();
     virtual void forward ();
     virtual void backward ();
-    virtual void jump (NodePtr e);
-    void play ();
-private slots:
-    void kioData (KIO::Job *, const QByteArray &);
-    void kioMimetype (KIO::Job *, const QString &);
-    void kioResult (KIO::Job *);
-protected:
-    virtual bool requestPlayURL (NodePtr mrl);
-    virtual bool resolveURL (NodePtr mrl);
+    virtual void play (Mrl *);
 private:
-    void read (NodePtr mrl, QTextStream &);
-    void stopResolving ();
-    struct ResolveInfo {
-        ResolveInfo (NodePtr mrl, KIO::Job * j, SharedPtr <ResolveInfo> & n)
-            : resolving_mrl (mrl), job (j), progress (0), next (n) {}
-        NodePtrW resolving_mrl;
-        KIO::Job * job;
-        QByteArray data;
-        int progress;
-        SharedPtr <ResolveInfo> next;
-    };
-    SharedPtr <ResolveInfo> m_resolve_info;
     bool activated; // 'solve' an singleShot race w/ cmdline url's
 };
 
@@ -111,43 +85,38 @@ private:
  */
 class KMPLAYER_EXPORT PartBase : public KMediaPlayer::Player {
     Q_OBJECT
-    K_DCOP
 public:
-    typedef QMap <QString, Process *> ProcessMap;
-    PartBase (QWidget * parent,  const char * wname,QObject * parent, const char * name, KConfig *);
+    PartBase (QWidget *parent, QObject *objParent, KSharedConfigPtr);
     ~PartBase ();
-    void init (KActionCollection * = 0L);
+    void init (KActionCollection *ac, const QString &objname, bool transparent);
     virtual KMediaPlayer::View* view ();
+    View* viewWidget () const { return m_view; }
     static KAboutData* createAboutData ();
 
     Settings * settings () const { return m_settings; }
     void keepMovieAspect (bool);
-    KURL url () const { return m_sources ["urlsource"]->url (); }
-    void setURL (const KURL & url) { m_sources ["urlsource"]->setURL (url); }
+    KUrl url () const { return m_sources ["urlsource"]->url (); }
+    void setUrl (const QString &url) { m_sources ["urlsource"]->setUrl (url); }
+    KUrl docBase () const { return m_docbase; }
 
-    /* Changes the process,
-     * calls setSource if process was playing
-     * */
-    void setProcess (const char *);
-    void setRecorder (const char *);
+    /* Changes the backend process */
+    QString processName (Mrl *mrl);
 
     /* Changes the source,
      * calls init() and reschedules an activate() on the source
      * */
     void setSource (Source * source);
+    void createBookmarkMenu (KMenu *owner, KActionCollection *ac);
     void connectPanel (ControlPanel * panel);
     void connectPlaylist (PlayListView * playlist);
     void connectInfoPanel (InfoWindow * infopanel);
     void connectSource (Source * old_source, Source * source);
-    Process * process () const { return m_process; }
-    Process * recorder () const { return m_recorder; }
+    MediaManager *mediaManager () const { return m_media_manager; }
     Source * source () const { return m_source; }
-    QMap <QString, Process *> & players () { return m_players; }
-    QMap <QString, Process *> & recorders () { return m_recorders; }
     QMap <QString, Source *> & sources () { return m_sources; }
-    KConfig * config () const { return m_config; }
+    KSharedConfigPtr config () const { return m_config; }
     bool mayResize () const { return !m_noresize; }
-    void updatePlayerMenu (ControlPanel *);
+    void updatePlayerMenu (ControlPanel *, const QString &backend=QString ());
     void updateInfo (const QString & msg);
     void updateStatus (const QString & msg);
 
@@ -155,15 +124,17 @@ public:
     void changeURL (const QString & url);
     void updateTree (bool full=true, bool force=false);
     void setLanguages (const QStringList & alang, const QStringList & slang);
+    void startRecording ();
+    void stopRecording ();
 public slots:
-    virtual bool openURL (const KURL & url);
-    virtual bool openURL (const KURL::List & urls);
-    virtual bool closeURL ();
+    virtual bool openUrl (const KUrl & url);
+    virtual bool openUrl (const KUrl::List & urls);
+    virtual void openUrl (const KUrl &, const QString &t, const QString &srv);
+    virtual bool closeUrl ();
     virtual void pause (void);
     virtual void play (void);
     virtual void stop (void);
     void record ();
-    virtual void seek (unsigned long msec);
     void adjustVolume (int incdec);
     bool playing () const;
     void showConfigDialog ();
@@ -177,14 +148,19 @@ public slots:
     void decreaseVolume ();
     void setPosition (int position, int length);
     virtual void setLoaded (int percentage);
+    virtual void processCreated (Process *);
 public:
     virtual bool isSeekable (void) const;
-    virtual unsigned long position (void) const;
+    virtual qlonglong position (void) const;
     virtual bool hasLength (void) const;
-    virtual unsigned long length (void) const;
-k_dcop:
+    virtual qlonglong length (void) const;
+    virtual void seek (qlonglong);
     void toggleFullScreen ();
     bool isPlaying ();
+
+    virtual QString doEvaluate (const QString &script);
+    void showControls (bool show);
+    QString getStatus ();
 signals:
     void sourceChanged (KMPlayer::Source * old, KMPlayer::Source * nw);
     void sourceDimensionChanged ();
@@ -200,6 +176,7 @@ signals:
     void audioIsSelected (int id);
     void subtitleIsSelected (int id);
     void positioned (int pos, int length);
+    void recording (bool);
 protected:
     bool openFile();
     virtual void timerEvent (QTimerEvent *);
@@ -213,29 +190,25 @@ protected slots:
     void saturationValueChanged (int val);
     void sourceHasChangedAspects ();
     void fullScreen ();
-    void playListItemClicked (QListViewItem *);
-    void playListItemExecuted (QListViewItem *);
+    void playListItemClicked (Q3ListViewItem *);
+    void playListItemExecuted (Q3ListViewItem *);
     virtual void playingStarted ();
     virtual void playingStopped ();
-    void recordingStarted ();
-    void recordingStopped ();
     void settingsChanged ();
     void audioSelected (int);
     void subtitleSelected (int);
 protected:
-    KConfig * m_config;
-    QGuardedPtr <View> m_view;
-    Settings * m_settings;
-    Process * m_process;
-    Process * m_recorder;
+    KUrl m_docbase;
+    KSharedConfigPtr m_config;
+    QPointer <View> m_view;
+    QMap <QString, QString> temp_backends;
+    Settings *m_settings;
+    MediaManager *m_media_manager;
     Source * m_source;
-    ProcessMap m_players;
-    ProcessMap m_recorders;
     QMap <QString, Source *> m_sources;
-    BookmarkManager * m_bookmark_manager;
+    KBookmarkManager * m_bookmark_manager;
     BookmarkOwner * m_bookmark_owner;
     KBookmarkMenu * m_bookmark_menu;
-    int m_record_timer;
     int m_update_tree_timer;
     bool m_noresize : 1;
     bool m_auto_controls : 1;
@@ -245,45 +218,6 @@ protected:
     bool m_update_tree_full : 1;
 };
 
-class KMPLAYER_NO_EXPORT DataCache : public QObject {
-    Q_OBJECT
-    typedef QMap <QString, QByteArray> DataMap;
-    typedef QMap <QString, bool> PreserveMap;
-    DataMap cache_map;
-    PreserveMap preserve_map;
-public:
-    DataCache () {}
-    ~DataCache () {}
-    void add (const QString &, const QByteArray &);
-    bool get (const QString &, QByteArray &);
-    bool preserve (const QString &);
-    bool unpreserve (const QString &);
-    bool isPreserved (const QString &);
-signals:
-    void preserveRemoved (const QString &); // ready or canceled
-};
-
-class KMPLAYER_NO_EXPORT RemoteObjectPrivate : public QObject {
-    Q_OBJECT
-public:
-    RemoteObjectPrivate (RemoteObject * r);
-    ~RemoteObjectPrivate ();
-    bool download (const QString &);
-    void clear ();
-    KIO::Job * job;
-    QString url;
-    QByteArray data;
-    QString mime;
-private slots:
-    void slotResult (KIO::Job*);
-    void slotData (KIO::Job*, const QByteArray& qb);
-    void slotMimetype (KIO::Job * job, const QString & mimestr);
-    void cachePreserveRemoved (const QString &);
-private:
-    RemoteObject * remote_object;
-    bool preserve_wait;
-};
-
 } // namespace
 
 #endif
